yakumo.nova.v2.quota_set

Package yakumo :: Package nova :: Package v2 :: Module quota_set |
[hide private]
[frames] | no frames]

# Module quota_set

source code

Resource class and its manager for Quota sets in Compute API v2

Classes | [hide private]
| Resource Resource class for Quota sets in Compute API v2
| Manager Manager class for Quota sets in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('cores', 'cores', mapper.Noop), ('fixed_i
      ps', 'fixed_ips', mapper.Noop), ('floating_ips', 'floating_ips', mappe
      r.Noop), ('injected_file_content_bytes', 'injected_file_content_bytes'
      , mapper.Noop), ('injected_file_path_bytes', 'injected_file_path_bytes
      ', mapper.Noop), ('injected_files', 'injected_files', mapper.Noop), ('
      instances', 'instances', mapper.Noop), ('key_pairs', 'key_pairs', mapp
      er.Noop), ('metadata_items', 'metadata_items', mapper.Noop), ('ram', '
      ram', mapper.Noop), ('security_group_rules', 'security_group_rules', m
      ...